@@ -12,6 +12,9 @@ import gzip
 import json
 import datetime
 import re
+import socket
+import tempfile
+import errno
 
 if sys.version_info[0] >= 3:
 	from socketserver import ThreadingTCPServer
@@ -69,11 +72,8 @@ class ServerHandler(SimpleHTTPRequestHandler):
 			fid.write(s.rfile.read(cl))
 
 		decompress(f)
-	
-		sha1 = hashlib.sha1()
-		with open(f, "rb") as fid:
-			sha1.update(fid.read())
-		h = sha1.hexdigest()
+
+		h = get_sha1sum_string(f)
 
 		with open(f, "rb") as fid:
 			for i, l in enumerate(fid):	pass
@@ -89,12 +89,29 @@ class ServerHandler(SimpleHTTPRequestHandler):
 
 	def do_upload_cap(s):
 		cl = int(s.headers['Content-Length'])
-		with open("dcrack.cap.tmp.gz", "wb") as fid:
+		tmp_cap = "/tmp/" + next(tempfile._get_candidate_names()) + ".cap"
+		with open(tmp_cap + ".gz", "wb") as fid:
 			fid.write(s.rfile.read(cl))
 
-		decompress("dcrack.cap.tmp")
-		os.rename("dcrack.cap.tmp.gz", "dcrack.cap.gz")
-		os.rename("dcrack.cap.tmp", "dcrack.cap")
+		decompress(tmp_cap)
+        
+		# Check file is valid
+		output = subprocess.check_output(['wpaclean', tmp_cap + ".tmp", tmp_cap])
+		try:
+			os.remove(tmp_cap + ".tmp")
+		except:
+			pass
+
+		output_split = output.splitlines()
+		if len(output_split) > 2:
+			# We got more than 2 lines, which means there is a network
+			#  in there with a WPA/2 PSK handshake
+			os.rename(tmp_cap + ".gz", "dcrack.cap.gz")
+			os.rename(tmp_cap, "dcrack.cap")
+		else:
+			 # If nothing in the file, just delete it
+			os.remove(tmp_cap)
+			os.remove(tmp_cap + ".gz")
 
 	def do_req(s, path):
 		con = get_con()
@@ -140,18 +157,43 @@ class ServerHandler(SimpleHTTPRequestHandler):
 		return "error"
 
 	def remove(s, path):
-		con = get_con()
-
 		p = path.split("/")
 		n = p[4].upper()
+		not_found = 0
 
+		# Validate BSSID
+		if not is_bssid_value(n):
+			return "NO"
+
+		con = get_con()
+
+		# Delete from nets
 		c = con.cursor()
-		c.execute("DELETE from nets where bssid = ?", (n,))
+		c.execute("SELECT * from nets where bssid = ?", (n,))
+		r = c.fetchall()
+		if r:
+			con.commit()
+			not_found += 1
+			c = con.cursor()
+			c.execute("DELETE from nets where bssid = ?", (n,))
 		con.commit()
 
-		c.execute("DELETE from work where net = ?", (n,))
+		# Delete from works
+		c = con.cursor()
+		c.execute("SELECT * from work where net = ?", (n,))
+		r = c.fetchall()
+		if r:
+			con.commit()
+			not_found += 1
+			c = con.cursor()
+			c.execute("DELETE from work where net = ?", (n,))
 		con.commit()
-		
+
+		# If both failed, return NO.
+		if not_found == 2:
+			return "NO"
+
+		# Otherwise, return OK
 		return "OK"
 
 	def get_status(s):
@@ -239,10 +281,13 @@ class ServerHandler(SimpleHTTPRequestHandler):
 
 		p = path.split("/")
 		n = p[4].upper()
+		if not is_bssid_value(n):
+			return "NO"
 
 		x  = urlparse(path)
 		qs = parse_qs(x.query)
 
+		# TODO: Verify client ID sending it
 		if "pass" in qs:
 			return s.do_result_pass(n, qs['pass'][0])
 
@@ -316,12 +361,31 @@ class ServerHandler(SimpleHTTPRequestHandler):
 		p = path.split("/")
 
 		n = p[4].upper()
+		# Validate BSSID
+		if not is_bssid_value(n):
+			return "NO"
 
+		# Only add network if it isn't already in there
+		# Update it if it failed cracking only
 		c = con.cursor()
-		c.execute("INSERT into nets values (?, NULL, 1)", (n,))
-		con.commit()
+		c.execute("SELECT * from nets where bssid = ?", (n,))
+		r = c.fetchone()
+		if r == None:
+			# Not in there, add it
+			c.execute("INSERT into nets values (?, NULL, 1)", (n,))
+			con.commit()
+			return "OK"
 
-		return "OK"
+		# Network already exists but has failed cracking
+		if r['state'] == 2 and r['pass'] == None:
+			c.execute("UPDATE nets SET state = 1 WHERE bssid = ?", (n,))
+			con.commit()
+			return "OK"
+
+        # State == 1: Just added or being worked on
+        # State == 2 and Pass exists: Already successfully cracked
+		con.commit()
+		return "NO"
 
 	def do_dict_set(s, path):
 		con = get_con()
@@ -329,6 +393,9 @@ class ServerHandler(SimpleHTTPRequestHandler):
 		p = path.split("/")
 
 		h = p[4]
+		# Validate hash
+		if not is_sha1sum(h):
+			return "NO"
 
 		c = con.cursor()
 		c.execute("UPDATE dict set current = 0")
@@ -501,11 +568,19 @@ def init_db():
 def server():
 	init_db()
 
-	server_class = ThreadingTCPServer 
-	httpd = server_class(('', port), ServerHandler)
+	server_class = ThreadingTCPServer
+	try:
+		httpd = server_class(('', port), ServerHandler)
+	except socket.error as exc:
+		print("Failed listening on port %d" % port)
+		return
 
 	print("Starting server")
-	httpd.serve_forever()
+	try:
+		httpd.serve_forever()
+	except KeyboardInterrupt:
+		print("Bye!")
+	httpd.server_close()
 
 def usage():
 	print("""dcrack v0.3
@@ -566,12 +641,24 @@ def get_work():
 	crack = json.loads(stuff)
 
 	if "interval" in crack:
-		print("Waiting")
-		return int(crack['interval'])
+		# Validate value
+		try:
+			interval = int(crack['interval'])
+			if (interval < 0):
+				raise ValueError('Interval must be above or equal to 0')
+		except:
+			# In case of failure, default to 60 sec
+			interval = 60
+		print("Waiting %d sec" % interval)
+		return interval
 
 	wl  = setup_dict(crack)
 	cap = get_cap(crack)
 
+	# If there's anything wrong with it, skip cracking
+	if wl == None or cap == None:
+		return
+
 	print("Cracking")
 
 	cmd = ["aircrack-ng", "-w", wl, "-b", crack['net'], "-q", cap]
@@ -618,6 +705,17 @@ def setup_dict(crack):
 	global url
 
 	d = crack['dict']
+	if not re.compile("^[a-f0-9]{5,40}").match(d):
+		print("Invalid dictionary: %s" % d)
+		return None
+
+	#if not re.match("^[0-9]+$", d['start']) or not re.match("^[0-9]+$", d['end']):
+	if crack['start'] < 0 or crack['end'] < 0:
+		print("Wordlist: Invalid start or end line positions")
+		return None
+	if crack['end'] <= crack['start']:
+		print("Wordlist: End line position must be greater than start position")
+		return None
 
 	fn = "dcrack-client-dict-%s.txt" % d
 
@@ -634,17 +732,14 @@ def setup_dict(crack):
 
 		print("Uncompressing dictionary")
 		decompress(fn)
-	
-		sha1 = hashlib.sha1()
-		with open(fn, "rb") as fid:
-			sha1.update(fid.read())
 
-		h = sha1.hexdigest()
+		h = get_sha1sum_string(fn)
 
 		if h != d:
-			print("bad dictionary")
-			exit(1)
+			print("Bad dictionary, SHA1 don't match")
+			return None
 
+	# Split wordlist
 	s = "dcrack-client-dict-%s-%d:%d.txt" \
 		% (d, crack['start'], crack['end']) 
 
@@ -659,6 +754,16 @@ def setup_dict(crack):
 						break
 					if i >= crack['start']:
 						fid2.write(l)
+
+	# Verify wordlist isn't empty
+	try:
+		if os.stat(s).st_size == 0:
+			print("Empty dictionary file!")
+			return None
+	except:
+		print("Dictionary does not exists!")
+		return None;
+
 	return s
 
 def get_cap(crack):
@@ -695,7 +800,8 @@ def get_cap(crack):
 	check_cap(fn, bssid)
 
 	if bssid not in nets:
-		raise BaseException("Can't find net %s" % bssid)
+		printf("Can't find net %s" % bssid)
+		return None
 
 	return fn
 
@@ -775,6 +881,7 @@ def client():
 
 	try_ping(speed)
 	t = threading.Thread(target=pinger, args=(speed,))
+	t.daemon = True
 	t.start()
 
 	while True:
@@ -791,7 +898,6 @@ def do_client():
 	except KeyboardInterrupt:
 		if cracker:
 			cracker.kill()
-		print("one more time...")
 
 def upload_file(url, f):
 	x  = urlparse(url)
@@ -821,13 +927,31 @@ def send_dict():
 
 	d = sys.argv[4]
 
-	print("Calculating dictionary hash for %s" % d)
+	# Check if file exists
+	try:
+		if os.stat(d).st_size == 0:
+			print("Empty dictionary file!")
+			return
+	except:
+		print("Dictionary does not exists!")
+		return;
 
-	sha1 = hashlib.sha1()
-	with open(d, "rb") as fid:
-		sha1.update(fid.read())
+	print("Cleaning up dictionary")
+	new_dict = "/tmp/" + next(tempfile._get_candidate_names()) + ".txt"
+	with open(new_dict, 'w') as fout:
+		with open(d) as fid:
+			for line in fid:
+				cleaned_line = line.rstrip("\n")
+				if len(cleaned_line) >= 8 and len(cleaned_line) <= 63:
+					fout.write(cleaned_line + "\n")
 
-	h = sha1.hexdigest()
+	if os.stat(new_dict).st_size == 0:
+		os.remove(new_dict)
+		print("No valid passphrase in dictionary")
+		return
+
+	print("Calculating dictionary hash for cleaned up %s" % d)
+	h = get_sha1sum_string(new_dict)
 
 	print("Hash is %s" % h)
 
@@ -837,9 +961,11 @@ def send_dict():
 	if "NO" in str(stuff):
 		u = url + "dict/create"
 		print("Compressing dictionary")
-		compress_file(d)
+		compress_file(new_dict)
+		os.remove(new_dict)
 		print("Uploading dictionary")
-		upload_file(u, d + ".gz")
+		upload_file(u, new_dict + ".gz")
+		os.remove(new_dict + ".gz")
 
 	print("Setting dictionary to %s" % d)
 	u = url + "dict/" + h + "/set"
@@ -854,18 +980,50 @@ def send_cap():
 
 	cap = sys.argv[4]
 
+	# Check if file exists
+	try:
+		if os.stat(cap).st_size <= 24:
+			# It may exists but contain no packets.
+			print("Empty capture file!")
+			return
+	except:
+		print("Capture file does not exists!")
+		return;
+
 	print("Cleaning cap %s" % cap)
-	subprocess.Popen(["wpaclean", cap + ".clean", cap], \
+	clean_cap = "/tmp/" + next(tempfile._get_candidate_names()) + ".cap"
+	subprocess.Popen(["wpaclean", clean_cap, cap], \
 	   stderr=subprocess.STDOUT, stdout=subprocess.PIPE).communicate()[0]
 
+	# Check cleaned file size (24 bytes -> 0 packets in file)
+	if os.stat(clean_cap).st_size <= 24:
+		print("Empty cleaned PCAP file, something's wrong with the original PCAP!")
+		return
+
 	print("Compressing cap")
-	compress_file(cap + ".clean")
+	compress_file(clean_cap)
+	os.remove(clean_cap)
 
 	u = url + "cap/create"
-	upload_file(u, cap + ".clean.gz")
+	ret = upload_file(u, clean_cap + ".gz")
+	if ret == "OK":
+		print("Upload successful")
+	elif ret == "NO":
+		print("Failed uploading wordlist")
+	else:
+		print("Unknown return value from server: %s" % (ret,))
+
+	# Delete temporary file
+	os.remove(clean_cap + ".gz")
 
 def cmd_crack():
-	net_cmd("crack")
+	ret = net_cmd("crack")
+	if ret == "OK":
+		print("Cracking job successfully added")
+	elif ret == "NO":
+		print("Failed adding cracking job!")
+	else:
+		print("Unknown return value from server: %s" % (ret,))
 
 def net_cmd(op):
 	global url
@@ -878,7 +1036,7 @@ def net_cmd(op):
 
 	print("%s %s" % (op, bssid))
 	u = "%snet/%s/%s" % (url, bssid, op)
-	stuff = urlopen(u).read()
+	return urlopen(u).read()
 
 def cmd_remove():
 	net_cmd("remove")
@@ -889,10 +1047,8 @@ def cmd_status():
 
 	stuff = json.loads(stuff.decode("utf-8"))
 
-#	print(stuff)
-#	print("=============")
-
 	speed = 0
+	idx = 0
 	for idx, c in enumerate(stuff['clients'], start=1):
 		speed += c
 
@@ -948,6 +1104,22 @@ def do_cmd():
 		print("Unknown cmd %s" % cmd)
 		usage()
 
+def get_sha1sum_string(f):
+		sha1 = hashlib.sha1()
+		with open(f, "rb") as fid:
+			sha1.update(fid.read())
+		return sha1.hexdigest()
+
+def is_sha1sum(h):
+	if re.match("[0-9a-fA-F]{40}", h):
+		return True
+	return False
+
+def is_bssid_value(b):
+	if re.match("([A-Fa-f0-9]{2}:){5}[A-Fa-f0-9]{2}", b):
+		return True
+	return False
+
 def main():
 	if len(sys.argv) < 2:
 		usage()
@@ -957,9 +1129,23 @@ def main():
 	if cmd == "server":
 		server()
 	elif cmd == "client":
-		client()
+		try:
+			client()
+		except KeyboardInterrupt:
+			pass
 	elif cmd == "cmd":
-		do_cmd()
+		try:
+			do_cmd()
+		except URLError as ue:
+			if "Connection refused" in ue.reason:
+				print("Connection to %s refused" % (sys.argv[2],))
+			else:
+				print(ue.reason)
+		except socket.error as se:
+			if se.errno == errno.ECONNREFUSED:
+				print("Connection refused")
+			else:
+				print(se)
 	else:
 		print("Unknown cmd", cmd)
 		usage()
