@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  *
  *  In addition, as a special exception, the copyright holders give
@@ -44,6 +44,7 @@
 #include "crypto.h"
 #include "pcap.h"
 #include "aircrack-osdep/byteorder.h"
+#include "aircrack-util/avl_tree.h"
 #include "aircrack-util/common.h"
 #include "aircrack-util/console.h"
 
@@ -79,6 +80,7 @@ char usage[] =
 
 struct decap_stats
 {
+	unsigned long nb_stations; /* # of stations seen */
 	unsigned long nb_read; /* # of packets read       */
 	unsigned long nb_wep; /* # of WEP data packets   */
 	unsigned long nb_bad; /* # of bad data packets   */
@@ -86,6 +88,8 @@ struct decap_stats
 	unsigned long nb_plain; /* # of plaintext packets  */
 	unsigned long nb_unwep; /* # of decrypted WEP pkt  */
 	unsigned long nb_unwpa; /* # of decrypted WPA pkt  */
+	unsigned long nb_failed_tkip; /* # of failed WPA TKIP pkt decryptions */
+	unsigned long nb_failed_ccmp; /* # of failed WPA CCMP pkt decryptions */
 } stats;
 
 struct options
@@ -108,7 +112,7 @@ unsigned char buffer2[65536];
 /* this routine handles to 802.11 to Ethernet translation */
 
 static int
-write_packet(FILE *f_out, struct pcap_pkthdr *pkh, unsigned char *h80211)
+write_packet(FILE * f_out, struct pcap_pkthdr * pkh, unsigned char * h80211)
 {
 	int n;
 	unsigned char arphdr[12];
@@ -126,26 +130,26 @@ write_packet(FILE *f_out, struct pcap_pkthdr *pkh, unsigned char *h80211)
 		{
 			case 0: /* To DS = 0, From DS = 0: DA, SA, BSSID */
 
-				memcpy(arphdr + 0, h80211 + 4, 6);
-				memcpy(arphdr + 6, h80211 + 10, 6);
+				memcpy(arphdr + 0, h80211 + 4, sizeof(arphdr) / 2);
+				memcpy(arphdr + 6, h80211 + 10, sizeof(arphdr) / 2);
 				break;
 
 			case 1: /* To DS = 1, From DS = 0: BSSID, SA, DA */
 
-				memcpy(arphdr + 0, h80211 + 16, 6);
-				memcpy(arphdr + 6, h80211 + 10, 6);
+				memcpy(arphdr + 0, h80211 + 16, sizeof(arphdr) / 2);
+				memcpy(arphdr + 6, h80211 + 10, sizeof(arphdr) / 2);
 				break;
 
 			case 2: /* To DS = 0, From DS = 1: DA, BSSID, SA */
 
-				memcpy(arphdr + 0, h80211 + 4, 6);
-				memcpy(arphdr + 6, h80211 + 16, 6);
+				memcpy(arphdr + 0, h80211 + 4, sizeof(arphdr) / 2);
+				memcpy(arphdr + 6, h80211 + 16, sizeof(arphdr) / 2);
 				break;
 
 			default: /* To DS = 1, From DS = 1: RA, TA, DA, SA */
 
-				memcpy(arphdr + 0, h80211 + 16, 6);
-				memcpy(arphdr + 6, h80211 + 24, 6);
+				memcpy(arphdr + 0, h80211 + 16, sizeof(arphdr) / 2);
+				memcpy(arphdr + 6, h80211 + 24, sizeof(arphdr) / 2);
 				break;
 		}
 
@@ -198,7 +202,12 @@ write_packet(FILE *f_out, struct pcap_pkthdr *pkh, unsigned char *h80211)
 	return (0);
 }
 
-int main(int argc, char *argv[])
+static int station_compare(const void * a, const void * b)
+{
+	return memcmp(a, b, 6);
+}
+
+int main(int argc, char * argv[])
 {
 	time_t tt;
 	unsigned magic;
@@ -207,12 +216,11 @@ int main(int argc, char *argv[])
 	unsigned long crc;
 	int i = 0, n, linktype;
 	unsigned z;
-	unsigned char *h80211;
+	unsigned char * h80211;
 	unsigned char bssid[6], stmac[6];
 
-	struct WPA_ST_info *st_1st;
-	struct WPA_ST_info *st_cur;
-	struct WPA_ST_info *st_prv;
+	c_avl_tree_t * stations = c_avl_create(station_compare);
+	struct WPA_ST_info * st_cur;
 	struct pcap_file_header pfh;
 	struct pcap_pkthdr pkh;
 
@@ -644,7 +652,6 @@ int main(int argc, char *argv[])
 
 	memset(&stats, 0, sizeof(stats));
 	tt = time(NULL);
-	st_1st = NULL;
 
 	while (1)
 	{
@@ -762,17 +769,17 @@ int main(int argc, char *argv[])
 		switch (h80211[1] & 3)
 		{
 			case 0:
-				memcpy(bssid, h80211 + 16, 6);
-				break; //Adhoc
+				memcpy(bssid, h80211 + 16, sizeof(bssid));
+				break; // Adhoc
 			case 1:
-				memcpy(bssid, h80211 + 4, 6);
-				break; //ToDS
+				memcpy(bssid, h80211 + 4, sizeof(bssid));
+				break; // ToDS
 			case 2:
-				memcpy(bssid, h80211 + 10, 6);
-				break; //FromDS
+				memcpy(bssid, h80211 + 10, sizeof(bssid));
+				break; // FromDS
 			case 3:
-				memcpy(bssid, h80211 + 10, 6);
-				break; //WDS -> Transmitter taken as BSSID
+				memcpy(bssid, h80211 + 10, sizeof(bssid));
+				break; // WDS -> Transmitter taken as BSSID
 		}
 
 		if (memcmp(opt.bssid, ZERO, 6) != 0)
@@ -783,35 +790,26 @@ int main(int argc, char *argv[])
 		switch (h80211[1] & 3)
 		{
 			case 1:
-				memcpy(stmac, h80211 + 10, 6);
+				memcpy(stmac, h80211 + 10, sizeof(stmac));
 				break;
 			case 2:
-				memcpy(stmac, h80211 + 4, 6);
+				memcpy(stmac, h80211 + 4, sizeof(stmac));
 				break;
 			case 3:
-				memcpy(stmac, h80211 + 10, 6);
+				memcpy(stmac, h80211 + 10, sizeof(stmac));
 				break;
 			default:
 				continue;
 		}
 
-		st_prv = NULL;
-		st_cur = st_1st;
-
-		while (st_cur != NULL)
-		{
-			if (!memcmp(st_cur->stmac, stmac, 6)) break;
-
-			st_prv = st_cur;
-			st_cur = st_cur->next;
-		}
+		int not_found = c_avl_get(stations, stmac, (void **) &st_cur);
 
 		/* if it's a new station, add it */
 
-		if (st_cur == NULL)
+		if (not_found)
 		{
-			if (!(st_cur = (struct WPA_ST_info *) malloc(
-					  sizeof(struct WPA_ST_info))))
+			if (!(st_cur
+				  = (struct WPA_ST_info *) malloc(sizeof(struct WPA_ST_info))))
 			{
 				perror("malloc failed");
 				break;
@@ -819,13 +817,10 @@ int main(int argc, char *argv[])
 
 			memset(st_cur, 0, sizeof(struct WPA_ST_info));
 
-			if (st_1st == NULL)
-				st_1st = st_cur;
-			else
-				st_prv->next = st_cur;
-
-			memcpy(st_cur->stmac, stmac, 6);
-			memcpy(st_cur->bssid, bssid, 6);
+			memcpy(st_cur->stmac, stmac, sizeof(st_cur->stmac));
+			memcpy(st_cur->bssid, bssid, sizeof(st_cur->bssid));
+			c_avl_insert(stations, st_cur->stmac, st_cur);
+			stats.nb_stations++;
 		}
 
 		/* check if we haven't already processed this packet */
@@ -846,7 +841,7 @@ int main(int argc, char *argv[])
 		}
 
 		/* check the SNAP header to see if data is encrypted *
-         * as unencrypted data begins with AA AA 03 00 00 00 */
+		 * as unencrypted data begins with AA AA 03 00 00 00 */
 
 		if (h80211[z] != h80211[z + 1] || h80211[z + 2] != 0x03)
 		{
@@ -879,7 +874,7 @@ int main(int argc, char *argv[])
 				}
 
 				/* WEP data packet was successfully decrypted, *
-                 * remove the WEP IV & ICV and write the data  */
+				 * remove the WEP IV & ICV and write the data  */
 
 				pkh.len -= 8;
 				pkh.caplen -= 8;
@@ -905,22 +900,33 @@ int main(int argc, char *argv[])
 				if (st_cur->keyver == 1)
 				{
 					if (decrypt_tkip(h80211, pkh.caplen, st_cur->ptk + 32) == 0)
+					{
+						stats.nb_failed_tkip++;
 						continue;
+					}
 
 					pkh.len -= 20;
 					pkh.caplen -= 20;
 				}
-				else
+				else if (st_cur->keyver == 2)
 				{
 					if (decrypt_ccmp(h80211, pkh.caplen, st_cur->ptk + 32) == 0)
+					{
+						stats.nb_failed_ccmp++;
 						continue;
+					}
 
 					pkh.len -= 16;
 					pkh.caplen -= 16;
 				}
+				else
+				{
+					fprintf(stderr, "unsupported keyver: %d\n", st_cur->keyver);
+					continue;
+				}
 
 				/* WPA data packet was successfully decrypted, *
-                 * remove the WPA Ext.IV & MIC, write the data */
+				 * remove the WPA Ext.IV & MIC, write the data */
 
 				if (pkh.caplen > z)
 				{
@@ -1036,9 +1042,12 @@ int main(int argc, char *argv[])
 					continue;
 				}
 
-				memcpy(st_cur->keymic, &h80211[z + 81], 16);
+				memcpy(st_cur->keymic, &h80211[z + 81], sizeof(st_cur->keymic));
 				memcpy(st_cur->eapol, &h80211[z], st_cur->eapol_size);
-				memset(st_cur->eapol + 81, 0, 16);
+				memset(
+					st_cur->eapol + 81,
+					0,
+					16); // where does this size come from? eapol is char[256]
 
 				/* copy the key descriptor version */
 
@@ -1049,12 +1058,13 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	while (st_1st != NULL)
+	/* cleanup avl tree */
+	void *key, *value;
+	while (c_avl_pick(stations, &key, &value) == 0)
 	{
-		st_cur = st_1st->next;
-		free(st_1st);
-		st_1st = st_cur;
+		free(value);
 	}
+	c_avl_destroy(stations);
 
 	fclose(f_in);
 	fclose(f_out);
@@ -1063,20 +1073,26 @@ int main(int argc, char *argv[])
 	/* write some statistics */
 
 	erase_line(2);
-	printf("Total number of packets read      %8lu\n"
+	printf("Total number of stations seen     %8lu\n"
+		   "Total number of packets read      %8lu\n"
 		   "Total number of WEP data packets  %8lu\n"
 		   "Total number of WPA data packets  %8lu\n"
 		   "Number of plaintext data packets  %8lu\n"
 		   "Number of decrypted WEP  packets  %8lu\n"
 		   "Number of corrupted WEP  packets  %8lu\n"
-		   "Number of decrypted WPA  packets  %8lu\n",
+		   "Number of decrypted WPA  packets  %8lu\n"
+		   "Number of bad TKIP (WPA) packets  %8lu\n"
+		   "Number of bad CCMP (WPA) packets  %8lu\n",
+		   stats.nb_stations,
 		   stats.nb_read,
 		   stats.nb_wep,
 		   stats.nb_wpa,
 		   stats.nb_plain,
 		   stats.nb_unwep,
 		   stats.nb_bad,
-		   stats.nb_unwpa);
+		   stats.nb_unwpa,
+		   stats.nb_failed_tkip,
+		   stats.nb_failed_ccmp);
 
 	return (0);
 }
