@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  *
  *  In addition, as a special exception, the copyright holders give
@@ -39,6 +39,7 @@
 #include <string.h>
 #include <sys/time.h>
 #include <time.h>
+#include <limits.h>
 #include <getopt.h>
 #include "version.h"
 #include "pcap.h"
@@ -117,10 +118,10 @@ struct options
 	unsigned char dip[4];
 	unsigned char sip[4];
 	unsigned char fctrl[2];
-	unsigned char *prga;
+	unsigned char * prga;
 
-	char *cap_out;
-	char *raw_file;
+	char * cap_out;
+	char * raw_file;
 
 	int mode;
 	int pktlen;
@@ -135,7 +136,7 @@ struct options
 	char fromds;
 	char encrypt;
 
-	FILE *ivs2;
+	FILE * ivs2;
 	unsigned char prev_bssid[6];
 	int first_packet;
 
@@ -148,7 +149,7 @@ struct devices
 	int fd_out, arptype_out;
 	int fd_rtc;
 
-	FILE *f_cap_in;
+	FILE * f_cap_in;
 
 	struct pcap_file_header pfh_in;
 } dev;
@@ -156,7 +157,7 @@ struct devices
 unsigned char h80211[2048];
 unsigned char tmpbuf[2048];
 
-static int capture_ask_packet(int *caplen)
+static int capture_ask_packet(int * caplen)
 {
 	time_t tr;
 	struct timeval tv;
@@ -372,7 +373,7 @@ static int capture_ask_packet(int *caplen)
 							   : h80211[i - 15 + j]);
 			}
 
-			if (i > 0 && ((i + 1) & 15) == 0)
+			if (i > 0 && i < INT_MAX && ((i + 1) & 15) == 0)
 			{
 				printf(" ");
 
@@ -397,7 +398,7 @@ static int capture_ask_packet(int *caplen)
 }
 
 /* IP address parsing routine */
-static int getip(char *s, unsigned char *ip, unsigned short *port)
+static int getip(char * s, unsigned char * ip, unsigned short * port)
 {
 	int i = 0, n;
 
@@ -428,7 +429,7 @@ static int getip(char *s, unsigned char *ip, unsigned short *port)
 	return (i != 4);
 }
 
-static unsigned short ip_chksum(unsigned short *addr, int count)
+static unsigned short ip_chksum(unsigned short * addr, int count)
 {
 	unsigned short checksum;
 	/* Compute Internet Checksum for "count" bytes
@@ -456,7 +457,7 @@ static unsigned short ip_chksum(unsigned short *addr, int count)
 	return checksum;
 }
 
-static int set_tofromds(unsigned char *packet)
+static int set_tofromds(unsigned char * packet)
 {
 	if (packet == NULL) return 1;
 
@@ -484,7 +485,7 @@ static int set_tofromds(unsigned char *packet)
 	return 0;
 }
 
-static int set_bssid(unsigned char *packet)
+static int set_bssid(unsigned char * packet)
 {
 	int mi_b;
 
@@ -518,7 +519,7 @@ static int set_bssid(unsigned char *packet)
 	return 0;
 }
 
-static int set_dmac(unsigned char *packet)
+static int set_dmac(unsigned char * packet)
 {
 	int mi_d;
 
@@ -552,7 +553,7 @@ static int set_dmac(unsigned char *packet)
 	return 0;
 }
 
-static int set_smac(unsigned char *packet)
+static int set_smac(unsigned char * packet)
 {
 	int mi_s;
 
@@ -587,7 +588,7 @@ static int set_smac(unsigned char *packet)
 }
 
 /* offset for ip&&udp = 48, for arp = 56 */
-static int set_dip(unsigned char *packet, const int offset)
+static int set_dip(unsigned char * packet, const int offset)
 {
 	if (packet == NULL) return 1;
 	if (offset < 0 || offset > 2046) return 1;
@@ -605,7 +606,7 @@ static int set_dip(unsigned char *packet, const int offset)
 }
 
 /* offset for ip&&udp = 44, for arp = 46 */
-static int set_sip(unsigned char *packet, const int offset)
+static int set_sip(unsigned char * packet, const int offset)
 {
 	if (packet == NULL) return 1;
 	if (offset < 0 || offset > 2046) return 1;
@@ -622,7 +623,7 @@ static int set_sip(unsigned char *packet, const int offset)
 	return 0;
 }
 
-static int set_ipid(unsigned char *packet, const int offset)
+static int set_ipid(unsigned char * packet, const int offset)
 {
 	unsigned short id;
 
@@ -636,7 +637,7 @@ static int set_ipid(unsigned char *packet, const int offset)
 	return 0;
 }
 
-static int set_ip_ttl(unsigned char *packet)
+static int set_ip_ttl(unsigned char * packet)
 {
 	unsigned char ttl;
 
@@ -648,7 +649,7 @@ static int set_ip_ttl(unsigned char *packet)
 	return 0;
 }
 
-static int set_IVidx(unsigned char *packet)
+static int set_IVidx(unsigned char * packet)
 {
 	if (packet == NULL) return 1;
 
@@ -664,13 +665,13 @@ static int set_IVidx(unsigned char *packet)
 	return 0;
 }
 
-static int next_keystream(unsigned char *dest,
+static int next_keystream(unsigned char * dest,
 						  const int size,
-						  unsigned char *bssid,
+						  unsigned char * bssid,
 						  const int minlen)
 {
 	struct ivs2_pkthdr ivs2;
-	char *buffer;
+	char * buffer;
 	int gotit = 0;
 
 	if (opt.ivs2 == NULL) return -1;
@@ -734,7 +735,7 @@ static int next_keystream(unsigned char *dest,
 }
 
 static int
-encrypt_data(unsigned char *dest, const unsigned char *data, const int length)
+encrypt_data(unsigned char * dest, const unsigned char * data, const int length)
 {
 	unsigned char cipher[2048];
 	int n;
@@ -790,7 +791,7 @@ encrypt_data(unsigned char *dest, const unsigned char *data, const int length)
 	return 0;
 }
 
-static int create_wep_packet(unsigned char *packet, int *length)
+static int create_wep_packet(unsigned char * packet, int * length)
 {
 	if (packet == NULL) return 1;
 
@@ -812,9 +813,9 @@ static int create_wep_packet(unsigned char *packet, int *length)
 	return 0;
 }
 
-static int write_cap_packet(unsigned char *packet, const int length)
+static int write_cap_packet(unsigned char * packet, const int length)
 {
-	FILE *f;
+	FILE * f;
 	struct pcap_file_header pfh;
 	struct pcap_pkthdr pkh;
 	struct timeval tv;
@@ -899,10 +900,10 @@ static int write_cap_packet(unsigned char *packet, const int length)
 	return 0;
 }
 
-static int read_prga(unsigned char **dest, const char *file)
+static int read_prga(unsigned char ** dest, const char * file)
 {
-	FILE *f;
-	size_t size;
+	FILE * f;
+	int size;
 	struct ivs2_filehdr fivs2;
 
 	if (file == NULL) return (1);
@@ -943,7 +944,7 @@ static int read_prga(unsigned char **dest, const char *file)
 
 	if (memcmp((*dest), IVS2_MAGIC, 4) == 0)
 	{
-		if (size < sizeof(struct ivs2_filehdr) + 4)
+		if ((size_t) size < sizeof(struct ivs2_filehdr) + 4)
 		{
 			fprintf(stderr, "No valid %s file.", IVS2_EXTENSION);
 			fclose(f);
@@ -964,7 +965,7 @@ static int read_prga(unsigned char **dest, const char *file)
 	}
 	else
 	{
-		//assuming old xor file
+		// assuming old xor file
 		if ((*dest)[3] > 0x03)
 		{
 			printf("Are you really sure that this is a valid keystream? "
@@ -1106,13 +1107,13 @@ static int forge_custom(void)
 
 static void print_usage(void)
 {
-	char *version_info = getVersion(
+	char * version_info = getVersion(
 		"Packetforge-ng", _MAJ, _MIN, _SUB_MIN, _REVISION, _BETA, _RC);
 	printf(usage, version_info);
 	free(version_info);
 }
 
-int main(int argc, char *argv[])
+int main(int argc, char * argv[])
 {
 	int arg;
 	int option_index;
